@@ -65,7 +65,7 @@ with other DBs.
 
 use v5.12;
 
-package SQL::Steno v0.2.4;
+package SQL::Steno v0.2.4.1;
 
 use strict;
 use warnings;
@@ -596,6 +596,7 @@ sub render_csv($;$$) {
     }
 }
 
+my( $r1, $r2, $r3, $r5 ) = ('[01]\d', '[0-2]\d', '[0-3]\d', '[0-5]\d');
 sub render_table($;$$) {
     my( $sth, $filter ) = @_;
     my( $null, $crlf, $date, $time ) =
@@ -621,18 +622,18 @@ sub render_table($;$$) {
 		$res1[$i] =~ s/([\t\n\r])/$esc{$1}/g;
 		no warnings 'uninitialized';
 		unless( $date ) {
-		    if( $res1[$i] =~ s/^(\d{4}-)(\d\d)-0[01]([T ]\d\d:\d\d(?::\d\d(?:\.\d{3})?)?Z?)?$/$1/ ) {
+		    if( $res1[$i] =~ s/^(\d{4}-)($r1)-0[01]([T ]$r2:$r5(?::$r5(?:[.,]\d{3})?)?(?:Z|[+-]$r2:$r5)?)?$/$1/o ) {
 			$res1[$i] .= "$2-" if $2 > 1;
 			$res1[$i] .= $3 if $3;
 		    }
 		}
 		unless( $time ) {
-		    if( $res1[$i] =~ s/^(\d{4}-(?:\d\d-(?:\d\d)?)?[T ])?(\d\d):(\d\d)(?::(\d\d)(?:\.(\d{3}))?)?(Z?)$/$1/ ) {
+		    if( $res1[$i] =~ s/^(\d{4}-(?:$r1-(?:$r3)?)?[T ])?($r2):($r5)(?::($r5)(?:([.,])(\d{3}))?)?(Z|[+-]$r2:$r5)?$/$1/o ) {
 			$res1[$i] = $1 || '';
-			if( $2 == 23 && $3 == 59 && ($4 // 59) == 59 && ($5 // 999) == 999 ) {
+			if( $2 == 23 && $3 == 59 && ($4 // 59) == 59 && ($6 // 999) == 999 ) {
 			    $res1[$i] .= "24:";
-			} elsif( $5 > 0 ) {
-			    $res1[$i] .= "$2:$3:$4.$5";
+			} elsif( $6 > 0 ) {
+			    $res1[$i] .= "$2:$3:$4$5$6";
 			} elsif( $4 > 0 ) {
 			    $res1[$i] .= "$2:$3:$4";
 			} elsif( $3 > 0 ) {
@@ -640,7 +641,8 @@ sub render_table($;$$) {
 			} else {
 			    $res1[$i] .= "$2:";
 			}
-			$res1[$i] .= $6;
+			($res1[$i] .= $7) =~ s/:00$/:/
+			    if $7;
 		    }
 		}
 		utf8::decode $res1[$i];
@@ -881,15 +883,15 @@ comma-separated options may be passed:
 
 =item >filename.suffix
 
-=item >filename.suffix( opt, ... )
+=item >filename.suffix( opt; ... )
 
 =item >>filename.suffix
 
-=item >>filename.suffix( opt, ... )
+=item >>filename.suffix( opt; ... )
 
-=item &.suffix opt, ...
+=item &.suffix opt; ...
 
-=item &.suffix( opt, ... ) following text
+=item &.suffix( opt; ... ) following text
 
 =back
 
@@ -909,7 +911,7 @@ can take one of these options:
 =item semi
 
 Use a semicolon as a separator.  This is a common format in environments where
-the comma is the decimal separator.  However if you want that, you must
+the comma is the decimal separator.  However if you want commas, you must
 provide such formatting yourself.
 
 =item tab
@@ -1046,7 +1048,7 @@ sub shell() {
 	}
 	s/^\s*()//;			# dummy because $1 survives loop iterations :-o
 	if( /\A(>{1,2})\s*(.+?(\.\w+)?)(?:\((.*)\))?\s*\Z/ ) {	# redirect output
-	    set_render $3, $4 ? split ',', $4 : () if $3;
+	    set_render $3, $4 ? split ';', $4 : () if $3;
 	    open $fh, "$1:utf8", (glob $2)[0];
 	    select $fh;
 	    goto NEXT;
